@@ -16,6 +16,9 @@
 
 namespace Aws\Common\Signature;
 
+use Aws\Common\Credentials\CredentialsInterface;
+use Guzzle\Http\Message\RequestInterface;
+
 abstract class AbstractSignature implements SignatureInterface
 {
     /**
@@ -27,4 +30,12 @@ abstract class AbstractSignature implements SignatureInterface
     {
         return time();
     }
+
+    public function createPresignedUrl(
+        RequestInterface $request,
+        CredentialsInterface $credentials,
+        $expires
+    ) {
+        throw new \BadMethodCallException(__METHOD__ . ' not implemented');
+    }
 }
